<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>License</source>
        <translation>Лицензия</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <location filename="../about.cpp" line="52"/>
        <source>Changelog</source>
        <translation>Список изменений</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="47"/>
        <source>GUI for applying assorted useful tweaks</source>
        <translation>Графическая оболочка для применения различных полезных настроек</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>launches brightness-systray</source>
        <translation>запускает brightness-systray</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>opens with display tab open.  Only valid with Xfce desktop running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Opens theme tab directly.  Valid on Xfce &amp; Fluxbox desktops</source>
        <translation>Открывает вкладку темы напрямую. Действует на рабочих столах Xfce и Fluxbox</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Opens Other tab directly.  Valid on all desktops</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Программная (xrandr) яркость</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation>Аппаратная подсветка</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="33"/>
        <source>MX-Tweak</source>
        <translation>MX-Tweak</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="58"/>
        <source>Display</source>
        <translation>Экран</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="63"/>
        <source>&amp;Quit</source>
        <translation>Выход</translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="57"/>
        <location filename="../defaultlook.cpp" line="86"/>
        <location filename="../defaultlook.cpp" line="657"/>
        <location filename="../defaultlook.cpp" line="676"/>
        <location filename="../defaultlook.cpp" line="685"/>
        <location filename="../defaultlook.cpp" line="732"/>
        <location filename="../defaultlook.cpp" line="740"/>
        <location filename="../defaultlook.cpp" line="767"/>
        <location filename="../defaultlook.cpp" line="770"/>
        <source>MX Tweak</source>
        <translation>MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="41"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Настроить панель&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="51"/>
        <location filename="../defaultlook.ui" line="272"/>
        <source>Panel</source>
        <translation>Панель</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="71"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Настроить поведение окон и сочетания клавиш&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="85"/>
        <source>Window Manager</source>
        <translation>Оконный менеджер</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="105"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Персонализация рабочего стола&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="119"/>
        <source>Appearance</source>
        <translation>Внешний вид</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="133"/>
        <source>Xfce Settings</source>
        <translation>Настройки Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="212"/>
        <source>About</source>
        <translation>О приложении</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="223"/>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="240"/>
        <source>Quit application</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="243"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="250"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="283"/>
        <source>Display panel horizontally</source>
        <extracomment>panel will be shown in a horizontal configuration</extracomment>
        <translation>Горизонтальное расположение</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="293"/>
        <source>Volume</source>
        <extracomment>volume plugin scale factor</extracomment>
        <translation>Том</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="300"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>affects the docklike plugin</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="307"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Влияет на все панели&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="327"/>
        <location filename="../defaultlook.ui" line="1811"/>
        <source>Bottom</source>
        <translation>Внизу</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="332"/>
        <location filename="../defaultlook.ui" line="1821"/>
        <source>Top</source>
        <translation>Сверху</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="340"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Tasklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Список задач&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="347"/>
        <source>Display panel vertically</source>
        <extracomment>panel will be shown in a vertical configuration</extracomment>
        <translation>Вертикальное расположение</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="362"/>
        <location filename="../defaultlook.ui" line="1800"/>
        <source>Affects 1st panel</source>
        <extracomment>acts on the first poanel found in Xfce panel xml fle</extracomment>
        <translation>Влияет на первую панель</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="369"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Panel Plugin Scales&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="389"/>
        <source>Backup current panel configuration</source>
        <extracomment>backup existing panel configuration</extracomment>
        <translation>Сохранить текущую конфигурацию панели</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="399"/>
        <location filename="../defaultlook.ui" line="459"/>
        <source>Options</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="419"/>
        <source>Power Manager</source>
        <extracomment>power manager plugin scale factor</extracomment>
        <translation>Диспетчер питания</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="426"/>
        <source>Restore backup panel configuration</source>
        <extracomment>restore a panel backup</extracomment>
        <translation>Восстановить конфигурацию панели</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="449"/>
        <source>Set Scales</source>
        <extracomment>set a scale factor</extracomment>
        <translation>Задать масштабы</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="479"/>
        <location filename="../defaultlook.ui" line="1816"/>
        <source>Left</source>
        <translation>Слева</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="484"/>
        <location filename="../defaultlook.ui" line="1826"/>
        <source>Right</source>
        <translation>Справа</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="492"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>affects the window button plugin</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Кнопки окон&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="513"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Docklike is the modern dock plugin for the panel.  Window Buttons is the classic tasklist without dock features.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="536"/>
        <location filename="../defaultlook.ui" line="735"/>
        <location filename="../defaultlook.ui" line="909"/>
        <location filename="../defaultlook.ui" line="1077"/>
        <location filename="../defaultlook.ui" line="1084"/>
        <location filename="../defaultlook.ui" line="1091"/>
        <location filename="../defaultlook.ui" line="1158"/>
        <location filename="../defaultlook.ui" line="1303"/>
        <location filename="../defaultlook.ui" line="1852"/>
        <location filename="../defaultlook.ui" line="1911"/>
        <location filename="../defaultlook.ui" line="2083"/>
        <source>Apply</source>
        <extracomment>apply changes</extracomment>
        <translation>Применить</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="556"/>
        <source>Restore default panel</source>
        <extracomment>affects any panel that is curently configured</extracomment>
        <translation>Вернуть панель по умолчанию</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="566"/>
        <source>Set Tasklist plugin to:</source>
        <extracomment>change the tasklist plugin</extracomment>
        <translation>Задать плагин Tasklist:</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="580"/>
        <source>Theme</source>
        <translation>Тема</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="651"/>
        <source>Size</source>
        <extracomment>size of the mouse pointer or cursor</extracomment>
        <translation>Размер</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="679"/>
        <source>Theme Options</source>
        <translation>Параметры темы</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="595"/>
        <source>Remove User Theme Set</source>
        <translation>Удалить пользовательскую настройку темы</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="588"/>
        <source>Preview</source>
        <translation>Предпросмотр</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="695"/>
        <source>Undo</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="606"/>
        <source>Save Current Settings as a Theme Set</source>
        <extracomment>save theme settings as a group</extracomment>
        <translation>Сохранить текущие настройки как набор тем</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="644"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Cursors&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>cursor theme</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="664"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Manager&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>theme a window manager border will get</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Менеджер окон&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="702"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Application&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>theme an application will get</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Приложения&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="637"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>icon theme</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Значки&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="630"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Themes&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Темы&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="758"/>
        <location filename="../defaultlook.ui" line="769"/>
        <source>Compositor</source>
        <translation>Композитор</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="776"/>
        <source>Transparency and shadow options</source>
        <translation>Параметры прозрачности и теней</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="875"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Править compton.conf в текстовом редакторе</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="878"/>
        <source>Edit compton.conf</source>
        <translation>Править compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="889"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Настройки композитора Xfce&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="892"/>
        <source>Xfwm Settings</source>
        <translation>Настройки Xfmw</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="851"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Изменение режима VBlank может смягчить некоторые проблемы тиринга. Для подробностей смотрите Справку.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="854"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="861"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Запустить конфигуратор compton-conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="864"/>
        <source>Compton settings</source>
        <translation>Настройки Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="796"/>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="617"/>
        <source>default</source>
        <extracomment>default pointer size determined by X server</extracomment>
        <translation>по умолчанию</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="801"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Композитор Xfwm (Xfce)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="806"/>
        <source>Compton </source>
        <translation>Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="815"/>
        <source>auto</source>
        <translation>авторежим</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="820"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="825"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="830"/>
        <location filename="../defaultlook.ui" line="1416"/>
        <source>off</source>
        <extracomment>setting to 0 turns off screensaver screen blank</extracomment>
        <translation>откл.</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="932"/>
        <source>Display</source>
        <translation>Экран</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="943"/>
        <source>Hardware Backlight</source>
        <extracomment>set the hardware backlight on monitors that have them</extracomment>
        <translation>Аппаратная подсветка</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="950"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Параметры экрана&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="977"/>
        <source>Choose Display for xrandr tweaks</source>
        <extracomment>choose the display that the xrandr tweaks will be acted upon</extracomment>
        <translation>Выберите экран для настроек xrandr</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="987"/>
        <source>Resolution</source>
        <translation>Разрешение</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="994"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Сохранить для этого экрана&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="997"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1004"/>
        <source>Software (xrandr) Brightness</source>
        <extracomment>adjust brightness (not backlight) via software</extracomment>
        <translation>Программная (xrandr) яркость</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1011"/>
        <location filename="../defaultlook.ui" line="1108"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1018"/>
        <source>GTK scaling</source>
        <extracomment>gtk scale factor</extracomment>
        <translation>Масштабирование GTK</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1038"/>
        <source>xrandr Scaling</source>
        <extracomment>xrandr scale factor</extracomment>
        <translation>Масштабирование xrandr</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1134"/>
        <source>Config Options</source>
        <translation>Параметры конфигурации</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1145"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Отключить укорачивание длинных имен на рабочем столе</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1169"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>примечание: для hibernate необходим swap &gt;= RAM</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1189"/>
        <source>Enable single-click on desktop</source>
        <translation>Задействовать одиночный щелчок на рабочем столе</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1196"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Добавить hibernate в меню Выхода из системы</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1203"/>
        <location filename="../defaultlook.ui" line="1337"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Сбросить на предустановленные действия по правому щелчку в Thunar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1210"/>
        <location filename="../defaultlook.ui" line="1388"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Задействовать одиночный щелчок в файловом менеджере Thunar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1217"/>
        <location filename="../defaultlook.ui" line="1649"/>
        <source>Thunar windows always open in split view</source>
        <translation>Окна Thunar всегда открываются в режиме раздельного просмотра</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1224"/>
        <location filename="../defaultlook.ui" line="1581"/>
        <source>Thunar split view opens horizontal</source>
        <translation>Разделенный просмотр Thunar открывается горизонтально</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1231"/>
        <source>Show percentages in notifcations when available</source>
        <translation>Показывать проценты в уведомлениях, если возможно</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1238"/>
        <source>Enable Desktop Zoom </source>
        <translation>Включить масштабирование рабочего стола</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1245"/>
        <location filename="../defaultlook.ui" line="1767"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Показывать на панели окна со всех рабочих столов</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1252"/>
        <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
        <translation>Показать кнопки действий файлового диалога GTK в нижней части окон</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1259"/>
        <source>( also turns off Client Side Decorations for Xfce applications)</source>
        <translation>(также отключает клиентское оформление для приложений Xfce)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1272"/>
        <source>Fluxbox</source>
        <translation>Fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1284"/>
        <location filename="../defaultlook.ui" line="1624"/>
        <source>On</source>
        <translation>Вкл</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1289"/>
        <location filename="../defaultlook.ui" line="1629"/>
        <source>Off</source>
        <translation>Откл.</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1310"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Thunar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Thunar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1317"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Toolbar Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Панель инструментов&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1357"/>
        <source>Toggle icon captions</source>
        <translation>Подписи значков</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1364"/>
        <source>Reset Fluxbox Menu</source>
        <translation>Сброс меню Fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1381"/>
        <source>Width</source>
        <translation>Ширина</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1395"/>
        <source>Toggle desktop icons</source>
        <translation>Значки на Рабочем столе</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1402"/>
        <location filename="../defaultlook.ui" line="1426"/>
        <source>Autohide</source>
        <translation>Скрывать автоматически</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1409"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Настройки дока&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1500"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Desktop Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Значки на Рабочем столе&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1574"/>
        <source>Reset DefaultDock</source>
        <translation>Сброс дока</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1588"/>
        <source>Manage Tint2 Panel</source>
        <translation>Управление панелью Tint2</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1599"/>
        <source>Height</source>
        <translation>Высота</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1606"/>
        <location filename="../defaultlook.ui" line="1642"/>
        <location filename="../defaultlook.ui" line="1774"/>
        <source>Placement</source>
        <translation>Размещение</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1613"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Screensaver&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>screensaver screen blank settings</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1634"/>
        <source>On Hover</source>
        <translation>При наведении</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1656"/>
        <location filename="../defaultlook.ui" line="1734"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reset Defaults&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Сбросить настройки по умолчанию&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1663"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Add new default menu items, if any, to existing fluxbox menu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Добавить элементы по умолчанию к существующему меню fluxbox.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1666"/>
        <source>Upgrade existing menu entries</source>
        <translation>Обновить существующие элементы</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1686"/>
        <source>Show Toolbar</source>
        <translation>Показать панель инструментов</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1703"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation>Сбросить ВСЕ настройки mx-fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1710"/>
        <source>Idle time (minutes)</source>
        <extracomment>set the time of inactivity  before screensaver screen blank occurs</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1723"/>
        <source>Plasma</source>
        <translation>Plasma</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1839"/>
        <source>Workspace</source>
        <translation>Рабочее место</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2101"/>
        <source>Change computer name (requires reboot)</source>
        <extracomment>option to change the system hostname, requires a reboot to be 100% effective</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1781"/>
        <source>Enable single-click</source>
        <translation>Использовать одиночный щелчок</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1788"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation>Сброс настроек KDE/Plasma</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1863"/>
        <source>Autostart plasma-discover system tray update notification utility</source>
        <extracomment>enable or disable autostartup of plasma-discover updater utility on login</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1873"/>
        <source>Super Key</source>
        <extracomment>referring to the meta or Left Super Key</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1881"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Choose application&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>description of button action to launch file dialog to choose an application</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1894"/>
        <source>Xfce-superkey defaults</source>
        <extracomment>indicates that xfce-superkey will select a command by its default logic</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1901"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Also known as the &amp;quot;windows&amp;quot; key&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1904"/>
        <source>Command to run with Super (Meta) key</source>
        <extracomment>label for the field to enter the command to use with super key</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1934"/>
        <source>Other</source>
        <translation>Другое</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2056"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Сбросить Lightdm (экран логина) к системной теме по умолчанию</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2015"/>
        <source>put a hold or remove a hold on updates of Liquorix kernels</source>
        <extracomment>toggle for apt hold action on update meta packages</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2018"/>
        <source>Enable Automatic Liquorix Kernel Updates (MX ahs repository)</source>
        <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2032"/>
        <source>put a hold or remove a hold on updates of Debian  kernels</source>
        <extracomment>toggle for apt hold action on update meta packages</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2035"/>
        <source>Enable Automatic Debian Kernel Updates</source>
        <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1956"/>
        <source>Password for administrative tasks:</source>
        <translation>Пароль для задач администрирования:</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2070"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Включить монтирование внешних носителей для не-root пользователей</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1963"/>
        <source>Root</source>
        <translation>Суперпользователь</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2001"/>
        <source>Enable kernel sandbox</source>
        <translation>Задействовать песочницу ядра</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1942"/>
        <source>&amp;User</source>
        <translation>&amp;Пользователь</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1984"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;requires reboot&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;требует перезагрузки&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1987"/>
        <source>Enable Bluetooth Adapters on boot</source>
        <translation>Включить адаптеры Bluetooth при загрузке</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1994"/>
        <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
        <translation>Apt устанавливает дополнительные «рекомендуемые» пакеты в качестве зависимостей</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2042"/>
        <source>Generate fluxbox All Apps menu after package installation, removal, and updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1970"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation>Использовать клиентское оформление окон (CSD) для приложений GTK3 (требуется перезапуск сеанса)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2025"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Использовать драйвер Intel вместо драйвера &quot;modesetting&quot; (требуется перезапуск)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1977"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>ПРИМЕЧАНИЕ: существующий /etc/X11/xorg.conf.d/20-intel.conf будет сохранен в домашней директории</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1949"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Использовать опцию amdgpu видео без тиринга</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2063"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>ПРИМЕЧАНИЕ: существующий /etc/X11/xorg.conf.d/20-amd.conf будет скопирован в домашний каталог</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2049"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Использовать опцию драйвера radeon видео без тиринга</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2008"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>ПРИМЕЧАНИЕ: существующий /etc/X11/xorg.conf.d/20-radeon.conf будет скопирован в домашний каталог</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="58"/>
        <source>--display switch only valid for Xfce</source>
        <translation>--переключатель экрана действует только в Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="656"/>
        <source>About MX Tweak</source>
        <translation>О MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="658"/>
        <source>Version: </source>
        <translation>Версия: </translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="659"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Приложение для быстрой доводки штатного оформления</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="661"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="662"/>
        <source>%1 License</source>
        <translation>%1 Лицензия</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="676"/>
        <source>%1 Help</source>
        <translation>%1 Справка</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="686"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Готово! Может потребоваться перезапуск Firefox</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="733"/>
        <source>Plese remove special characters</source>
        <translation>Удалите специальные символы</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="733"/>
        <source>from file name</source>
        <translation>из имени файла</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="740"/>
        <source>File name already exists.  Choose another name</source>
        <translation>Файл уже существует. Выберите другое имя</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="768"/>
        <source>File is not a valid tar.xz archive file</source>
        <translation>Файл не является tar.xz архивом</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="771"/>
        <source>Archive does not contain a panel config</source>
        <translation>Архив не содержит настройки панели</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="946"/>
        <source>Panel settings</source>
        <translation>Настройки панели</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="947"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>Ваши настройки панели были сохранены в скрытой папке .restore домашнего каталога (~/.restore/)</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1838"/>
        <source>settings</source>
        <translation>настройки</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="2178"/>
        <source>Choose a theme set</source>
        <translation>Выберите набор темы</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="2584"/>
        <source>Please enter a computer name.</source>
        <comment>question to enter a name for the computer hostname</comment>
        <translation>Пожалуйста, введите имя компьютера.</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="2588"/>
        <source>Sorry, your computer name contains invalid characters.
You&apos;ll have to select a different
name before proceeding.</source>
        <comment>unacceptable characters are found in hostname, pick a new name</comment>
        <translation>Извините, имя компьютера содержит недопустимые символы. Для продолжения выберите другое имя.</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="4146"/>
        <source>Select application to run</source>
        <comment>will show in file dialog when selection an application to run</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Удалить набор тем пользователя</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Новая настройка темы</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Введите имя для настройки темы</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="24"/>
        <source>Window Buttons</source>
        <translation>Кнопки окон</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Внешний вид&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Показывать подписи кнопок</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Показывать плоские кнопки</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Показывать ручку</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Порядок сортировки:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Метка времени</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Сгруппировать название и метку времени</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Заголовок окна</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Сгруппировать название приложения и заголовок окна</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Нет, разрешить перетаскивание</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Поведение&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Группировать окна:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Никогда</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Всегда</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Действие по щелчку средней кнопкой мыши:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Ничего</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Закрыть окно</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Свернуть окно</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Разворачивать свёрнутые окна на текущий рабочий стол</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Отображать рамку окна под курсором мыши</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Переключать окна с помощью колёсика мыши</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Фильтрация&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Показывать окна со всех рабочих мест или видов</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Показывать только свёрнутые окна</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Показывать окна со всех мониторов</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Диалоговое окно</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Всплывающие окна</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Окна при перетаскивании</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Настройки непрозрачности&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Оформление окон</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Отображать тени у уменьшенных (dock) окон</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Отображать тени у всплывающих окон</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Окна при изменении размеров</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Отображать тени у обычных окон</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Настройки возможностей&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Показывать предпросмотр окна вместо значков при прокрутке</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Напрямую отображать полноэкранные оверлей окна</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Неактивные окна</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Синхронизировать отрисовку по вертикальной очистке</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="23"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Настройки композитора Xfwm</translation>
    </message>
</context>
</TS>
